@@ -1,4 +1,13 @@
-import json, os, subprocess, re
+try:
+    import json
+except ImportError:
+    try:
+        import simplejson
+    except:
+        print "You need at least simplejson - http://pypi.python.org/pypi/simplejson - to continue with pypalm"
+        exit()
+
+import os, subprocess, re
 import StringIO
 
 
